repos:
  - repo: local
    hooks:
      - id: reject-no-push-title
        name: Reject NO-PUSH in last commit title, adapt comment to the proper location
        entry: bash -c '[[ ! "$(git log -1 --pretty=%s)" =~ NO-PUSH ]]'
        language: system
        pass_filenames: false
        stages: [push]
