[build-system]
requires = ["poetry-core"]
build-backend = "poetry.core.masonry.api"

[project]
name = "{{package_name}}"
version = "{{version.major}}.{{version.minor}}.{{version.patch}}{{version.finalacronym}}"
description = "{{description}}"
readme = "README.md"
requires-python = "{{version.relationship}}{{version.major}}.{{version.minor}}"
license = { text = "MIT" }
authors = [{ name = "{{ author.first_name + ' ' if author.first_name else '' }}{{ author.middle_name + ' ' if author.middle_name else '' }}{{ author.last_name}}", email = "{{author.email}}" }]
dependencies = [
     "pydantic==2.12.5"
]

[project.optional-dependencies]
dev = [
    "black==25.11.0",
    "isort==7.0.0",
    "pytest==9.0.2",
    "mypy==1.19.0",
    "wemake-python-styleguide==1.4.0",
    "poetry==2.2.1"
]

[project.scripts]
scaffoldry = "scaffoldry.main:main"

[project.urls]
Homepage = "https://github.com/{{author_repository}}/{repository_name}}"

[tool.poetry]
packages = [{ include = "{{package_name}}", from = "src" }]

[tool.black]
line-length = 80
target-version = ["py{{version.major}}{{version.minor}}"]
include = "src/"

[tool.isort]
profile = "black"
src_paths = ["src"]
line_length = 80

[tool.pytest.ini_options]
testpaths = ["tests"]
pythonpath = ["src"]
addopts = "--cov=src --cov-report=term-missing --cov-fail-under=80 -q"
python_files = "test_*.py"

[tool.mypy]
python_version = "{{version.major}}.{{version.minor}}"
strict = true
packages = ["{{package_name}}"]
